@@ -11,17 +11,15 @@ log_format = logging.Formatter(
 
 console_handler = logging.StreamHandler(stream=sys.stdout)
 console_handler.setFormatter(log_format)
-console_handler.setLevel(logging.DEBUG)
+console_handler.setLevel(logging.INFO)
 
 logger = logging.getLogger("DengUtils")
 logger.addHandler(console_handler)
-logger.setLevel(logging.DEBUG)
+logger.setLevel(logging.INFO)
 
 
 def clean_handler():
     for handler in logger.handlers:
-        handler.flush()
-        handler.close()
         logger.removeHandler(handler)
 
 
@@ -37,11 +35,6 @@ def configure_logger(
     :param log_file: 日志文件存储路径
     :param append: 是否为追加模式。当为覆盖模式时会清空已有的handler再添加新的
     """
-
-    # 非追加模式时，先清空所有已有的handler
-    if not append:
-        clean_handler()
-
     # 设置日志级别
     if level in (
         logging.NOTSET,
@@ -57,6 +50,12 @@ def configure_logger(
     for handler in logger.handlers:
         handler.setLevel(level)
 
+    # 非追加模式时，先清空所有已有的handler
+    # 必须放置在设置已有Handler日志级别之后，因为已有的Handler可能被别处引用
+    # 如果放置在最前面会导致在别处引用的handler日志级别无法受level参数控制
+    if not append:
+        clean_handler()
+
     # 往日志句柄中添加处理器
     if handlers:
         for handler in handlers:
