@@ -189,8 +189,8 @@ class MyCache(object):
         self._dict[key] = value
         self.save_cache()
 
-    def setex(self, key, time, value):
-        self._dict[key] = value
+    def setex(self, name, time, value):
+        self._dict[name] = value
         self.save_cache()
 
     def hmset(self, key: str, value):
