@@ -24,7 +24,7 @@ def get_current_time(
     part1 = time.localtime(part1 - offset)
     if _format.lower() == "short":
         return time.strftime(f"%Y{sep1}%m{sep1}%d", part1)
-    else:
+    elif _format.lower() == "long":
         _temp = time.strftime(
             f"%Y{sep1}%m{sep1}%d %H{sep2}%M{sep2}%S", part1
         )
@@ -32,6 +32,8 @@ def get_current_time(
             return _temp + str(part2)[1:8]
         else:
             return _temp
+    else:
+        return time.strftime(_format, part1)
 
 
 def str_to_time(time_str: str, _format="long"):
